Module guards

Module guards 

Guards for specific flows

Modules

any
Accepts any payment that the vendor accepts.
attached_cycles
caller_pays_icrc2_cycles
Code to receive cycles as payment, credited to the canister, using ICRC-2 and a cycles-ledger specific withdrawal method.
caller_pays_icrc2_tokens
Code to receive any ICRC-2 token as payment.
patron_pays_icrc2_cycles
Code to receive cycles as payment, credited to the canister, using ICRC-2 and a cycles-ledger specific withdrawal method.
patron_pays_icrc2_tokens
Code to receive cycles as payment, credited to the canister, using ICRC-2 and a cycles-ledger specific withdrawal method.

Traits

PaymentGuardTrait