Guards for specific flows
Modules
- any
- Accepts any payment that the vendor accepts.
- attached_
cycles - caller_
pays_ icrc2_ cycles - Code to receive cycles as payment, credited to the canister, using ICRC-2 and a cycles-ledger specific withdrawal method.
- caller_
pays_ icrc2_ tokens - Code to receive any ICRC-2 token as payment.
- patron_
pays_ icrc2_ cycles - Code to receive cycles as payment, credited to the canister, using ICRC-2 and a cycles-ledger specific withdrawal method.
- patron_
pays_ icrc2_ tokens - Code to receive cycles as payment, credited to the canister, using ICRC-2 and a cycles-ledger specific withdrawal method.